<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

// if the WC payment gateway class is not available, do nothing
if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
	return;
}

/**
 * Class WC_Verifone
 */
abstract class WC_Verifone extends \WC_Payment_Gateway {

	protected $plugin_name;
	protected $version;

	/**
	 * @var \WC_Verifone_Token
	 */
	protected $token_helper;

	/**
	 * @var \Verifone_Hosted_Helper
	 */
	protected $verifone_helper;

	/**
	 * @var \Verifone_Hosted_Cart_Settings
	 */
	protected $verifone_settings;

	/**
	 * @var \Verifone_Hosted_Cart_Logger
	 */
	protected $logger;

	/**
	 * @var \Api_Mapper
	 */
	protected $api_url_mapper;

	/**
	 * @var \Simple_Curl
	 */
	protected $simple_curl;

	const PLUGIN_ID = 'verifone_hosted_cart';

	/**
	 * WC_Verifone_Hosted_Cart constructor.
	 */
	public function __construct() {
		//Initialize all the basics components of the plugin
		$this->plugin_name        = 'Verifone Hosted Cart Payment';
		$this->method_description = __( 'Verifone secure card payments via hosted cart', 'woocommerce' );
		$this->supports[]         = 'refunds';
		$this->order_button_text = __( 'Proceed to Verifone Hosted Cart', 'woocommerce' );
		$this->method_title      = __( 'Verifone Hosted Cart', 'woocommerce' );
		$this->version    = '1.0.1';
		$this->id         = self::PLUGIN_ID;
		$this->enabled    = $this->get_option( 'enabled' );
		$this->has_fields = false;
		// Define user set variables
		$this->title       = $this->get_option( 'title' );
		$this->description = $this->get_option( 'description' );

		// Load the settings
		$this->init_form_fields();
		$this->init_settings();
		$settings = new Verifone_Hosted_Cart_Settings();
		$settings->setTest('Test' ==  $this->get_option( 'test' ) )
		         ->setRegion( $this->get_option( 'region' ) )
		         ->setApiUsername( $this->get_option( 'api_username' ) )
		         ->setApiPassword( $this->get_option( 'api_password' ) )
		         ->setApiClientId( $this->get_option( 'api_client_id' ) )
		         ->setTestApiUsername( $this->get_option( 'test_api_username' ) )
		         ->setTestApiPassword( $this->get_option( 'test_api_password' ) )
		         ->setTestApiClientId( $this->get_option( 'test_api_client_id' ) )
		         ->set3dsEnable( 'yes' == $this->get_option( '_3ds_enable' ) || 'Yes' == $this->get_option( '_3ds_enable' ) )
		         ->setOverlayOnPlaceOrder( 'yes' == $this->get_option( 'overlay_on_place_order' ) || 'Yes' == $this->get_option( 'overlay_on_place_order' ) )
		         ->set3dsContractId( $this->get_option( '_3ds_contract_id' ) )
		         ->setPaymentContractId( $this->get_option( 'payment_contract_id' ) )
		         ->setEntityId( $this->get_option( 'entity_id' ) )
		         ->setTestEntityId( $this->get_option( 'test_entity_id' ) )
		         ->setTestPaymentContractId( $this->get_option( 'test_payment_contract_id' ) )
		         ->setTest3dsContractId( $this->get_option( 'test_3ds_contract_id' ) )
		         ->setCurlVerifySsl( 'yes' == $this->get_option( 'curl_verify_ssl' ) || 'Yes' == $this->get_option( 'curl_verify_ssl' ) )
			// removed until january fix
//		         ->setCvvOnPayment( 'yes' == $this->get_option( 'cvv_on_payment' ) || 'Yes' == $this->get_option( 'cvv_on_payment' ) )
	         ->setCvvOnPayment( true )
		;

		$this->verifone_settings = $settings;
		$this->logger   = new Verifone_Hosted_Cart_Logger();
		$this->simple_curl = new Simple_Curl();

		// mini factory :D
		switch($this->get_option( 'region' )) {
			case 'NZAU':
				$this->api_url_mapper = new Nzau_Verifone_Api_Mapper($this->verifone_settings);
				break;
			case 'NA':
				$this->api_url_mapper = new Na_Verifone_Api_Mapper($this->verifone_settings);
				break;
			case 'EMEA':
				$this->api_url_mapper = new Emea_Verifone_Api_Mapper($this->verifone_settings);
				break;
			default:
				// will happen only on the first installation
				$this->api_url_mapper = new Nzau_Verifone_Api_Mapper($this->verifone_settings);
		}

		$this->token_helper = new WC_Verifone_Token( $this->verifone_settings, $this->api_url_mapper, $this->logger , $this->simple_curl);
		$this->verifone_helper = new Verifone_Hosted_Helper();
	}

}
