<?php

/**
 * Class Verifone_Hosted_Checkout
 */
class Verifone_Hosted_Checkout extends Verifone_Api_Entity {

	/**
	 * @var string
	 */
	private $customer_id;

	/**
	 * @var \Verifone_Hosted_Helper
	 */
	private $helper;

	/**
	 * @var \Verifone_Hosted_Cart_Settings
	 */
	private $settings;

	/**
	 * @var \WC_Order
	 */
	private $order;

	/**
	 * @var array
	 */
	protected $data;

	/**
	 * Verifone_Hosted_Checkout constructor.
	 *
	 * @param \WC_Order                      $order
	 * @param \Verifone_Hosted_Cart_Settings $settings
	 * @param \Verifone_Hosted_Helper        $helper
	 * @param string                         $customer_id
	 *
	 * @throws \Exception
	 */
	public function __construct(
		WC_Order $order,
		Verifone_Hosted_Cart_Settings $settings,
		Verifone_Hosted_Helper $helper,
		$customer_id = ''
	) {
		$this->order       = $order;
		$this->customer_id = $customer_id;
		$this->helper      = $helper;
		$this->settings    = $settings;

		$this->buildData();
	}

	/**
	 * @throws \Exception
	 */
	private function buildData() {
		$customer_data = [];
		if ( $this->customer_id !== '' ) {
			$customer_data['customer'] = $this->customer_id;
		}

		$configurations = [
			'configurations' => [
				'card' => [
					'cvvRequired'       => $this->settings->getCvvOnPayment(),
					'captureNow'        => true,
					'paymentContractId' => $this->settings->getPaymentContractId(),
				],
			],
		];

		if ( $this->settings->is3dsEnabled() ) {
			$configurations['configurations']['card']['threedSecure'] = [
				'threeDSContractId' => $this->settings->get3dsContractId(),
				'enabled'           => $this->settings->is3dsEnabled(),
				'transactionMode'   => $this->helper->getDeviceType(),
			];
		}

		$amount = absint( wc_format_decimal( ( (float) $this->order->get_total() * 100 ), wc_get_price_decimals() ) );
		$params = [
			'amount'            => $amount,
			'currencyCode'      => strtoupper( get_option( 'woocommerce_currency' ) ),
			'entityId'          => $this->settings->getEntityId(),
			// must be a string
			'merchantReference' => sprintf( '%s', $this->order->get_id() ),
			'returnUrl'         => add_query_arg( [
				'wc-api' => 'payment_response',
				'pm' => 'verifone_hosted'
			], home_url( '/' ) ),
		];

		$this->data = $params;
		$this->data = array_merge( $this->data, $customer_data );
		$this->data = array_merge( $this->data, $configurations );
	}

	/**
	 * @return array
	 */
	public function toArray() {
		return $this->data;
	}

	/**
	 * @return false|string
	 */
	public function toJson() {
		return json_encode( $this->data );
	}

}
