<?php

/**
 * Class Verifone_Hosted_Customer
 */
class Verifone_Hosted_Customer extends Verifone_Api_Entity {

	/**
	 * @var \WC_Order
	 */
	private $order;

	/**
	 * @var array
	 */
	protected $data;

	/**
	 * @var \Verifone_Hosted_Cart_Settings
	 */
	private $settings;

	/**
	 * Verifone_Hosted_Customer constructor.
	 *
	 * @param \WC_Order                      $order
	 * @param \Verifone_Hosted_Cart_Settings $settings
	 */
	public function __construct(
		WC_Order $order, Verifone_Hosted_Cart_Settings $settings
	) {
		$this->order    = $order;
		$this->settings = $settings;
		$this->data     = $this->buildData();
	}

	/**
	 * @return array
	 */
	private function buildData() {
		$data = [];
		if ( ! empty( $this->order->get_billing_company() ) ) {
			$data['companyName'] = substr( $this->order->get_billing_company(), 0, 100 );
		}
		$data['emailAddress'] = substr( $this->order->get_billing_email(), 0, 250 );
		$data['entityId']     = $this->settings->getEntityId();

		$data = array_merge( $data, $this->getBillingDetails() );

		return array_merge( $data, $this->getShippingDetails() );
	}

	/**
	 * @return array
	 */
	private function getShippingDetails() {
		// use billing details if no shipping details are found
		if ( '' === $this->order->get_shipping_address_1() ) {
			return [
				'shipping' => $this->createBillingDetails(),
			];
		}

		$shipping = [
			'address1'    => substr( $this->order->get_shipping_address_1(), 0, 40 ),
			'city'        => substr( $this->order->get_shipping_city(), 0, 40 ),
			'countryCode' => $this->order->get_shipping_country(),
			'postalCode'  => substr( $this->order->get_shipping_postcode(), 0, 10 ),
			'state'       => substr( $this->order->get_shipping_state(), 0, 50 ),
			'firstName'   => substr( $this->order->get_shipping_first_name(), 0, 50 ),
			'lastName'    => substr( $this->order->get_shipping_last_name(), 0, 50 ),
			'phone'       => preg_replace( '/[^0-9]+/', '', substr( $this->order->get_billing_phone(), 0, 20 ) ),
		];

		if ( '' !== $this->order->get_shipping_address_2() ) {
			$shipping['address2'] = substr( $this->order->get_shipping_address_2(), 0, 40 );
		}

		return [
			'shipping' => $shipping,
		];
	}

	/**
	 * @return array
	 */
	private function createBillingDetails() {
		$billing = [
			'address1'    => substr( $this->order->get_billing_address_1(), 0, 40 ),
			'city'        => substr( $this->order->get_billing_city(), 0, 40 ),
			'countryCode' => strtoupper( $this->order->get_billing_country() ),
			'firstName'   => substr( $this->order->get_billing_first_name(), 0, 50 ),
			'lastName'    => substr( $this->order->get_billing_last_name(), 0, 50 ),
			'phone'       => preg_replace( '/[^0-9]+/', '', substr( $this->order->get_billing_phone(), 0, 20 ) ),
			'postalCode'  => substr( $this->order->get_billing_postcode(), 0, 10 ),
			'state'       => substr( $this->order->get_billing_state(), 0, 50 ),
		];

		if ( '' !== $this->order->get_billing_address_2() ) {
			$billing['address2'] = substr( $this->order->get_billing_address_2(), 0, 40 );
		}

		return $billing;
	}

	/**
	 * @return array
	 */
	private function getBillingDetails() {
		return [
			'billing' => $this->createBillingDetails(),
		];
	}

	/**
	 * @return array
	 */
	public function toArray() {
		return $this->data;
	}

	/**
	 * @return false|string
	 */
	public function toJson() {
		return json_encode( $this->data );
	}

}
