<?php

/**
 * Class Simple_Curl
 */
class Simple_Curl {

	/**
	 * @var false|resource
	 */
	private $ch;

	/**
	 * @var \WC_Logger
	 */
	private $logger;

	/**
	 * Simple_Curl constructor.
	 */
	public function __construct() {
		$this->logger = new WC_Logger();

		// close any unclosed connections
		if ( is_resource( $this->ch ) ) {
			curl_close( $this->ch );
		}

		$this->ch = curl_init();
	}

	/**
	 * @param $option
	 * @param $value
	 *
	 * @return $this
	 * @throws \Exception
	 */
	public function setOpt( $option, $value ) {
		// do we have an open connection?
		if(!is_resource($this->ch)) {
			$this->ch = curl_init();
		}

		if(false === curl_setopt( $this->ch, $option, $value ) ) {
			$this->logger->alert( sprintf('There was an error when setting the curl option with name %s', $option) );
			throw new Exception( 'There was an error in the application' );
		}

		return $this;
	}

	/**
	 * @return mixed
	 * @throws \Exception
	 */
	public function getResult() {
		$result = curl_exec( $this->ch );
		$info   = curl_getinfo($this->ch );
		if ( curl_errno( $this->ch ) ) {
			$this->logger->alert( curl_error( $this->ch ) );
			throw new Exception( 'There was an error in the application' );
		}
		curl_close( $this->ch );

		if ( ! isset( $info['http_code'] ) )  {
			$this->logger->alert( sprintf( 'cURL failed or did not return a 200 OK status at %s line in %s file', __LINE__, __FILE__ ) );
			throw new Exception( 'There was an error in the application' );
		}

		switch($info['http_code'] ) {
			case 404:
			case 500:
				throw new Exception( 'There was an error in the application' );
		}

		return $result;
	}

}
