<?php

/**
 * Class Nzau_Verifone_Api_Mapper
 */
final class Nzau_Verifone_Api_Mapper implements Api_Mapper {

	const NZAU_ENV_LIVE_CUSTOMER_URL = 'https://nz.gsc.verifone.cloud';

	const NZAU_ENV_TEST_CUSTOMER_URL = 'https://cst2.test-gsc.vfims.com';

	const NZAU_ENV_LIVE_CHECKOUT_URL = 'https://checkout_nz.dimebox.com';

	const NZAU_ENV_TEST_CHECKOUT_URL = 'https://checkout_cst.dimebox.com';

	const NZAU_ENV_LIVE_PAYMENTS_BASE_URL = 'https://nz.gsc.verifone.cloud';

	const NZAU_ENV_TEST_PAYMENTS_BASE_URL = 'https://cst2.test-gsc.vfims.com';

	const NZAU_ENV_LIVE_TOKEN_URL = 'https://nz.vam.verifone.cloud';

	const NZAU_ENV_TEST_TOKEN_URL = 'https://cst1.test-vam.vfims.com';

	const NZAU_ENV_LIVE_TOKEN_REDIRECT_URI = 'https://nz.live.verifone.cloud/';

	const NZAU_ENV_TEST_TOKEN_REDIRECT_URI = 'http://localhost/';

	/**
	 * @var \Verifone_Hosted_Cart_Settings
	 */
	private $settings;

	/**
	 * Verifone_Api_Mapper constructor.
	 *
	 * @param \Verifone_Hosted_Cart_Settings $settings
	 */
	public function __construct( Verifone_Hosted_Cart_Settings $settings ) {
		$this->settings = $settings;
	}

	/**
	 * @return mixed|string
	 */
	public function getTokenRedirectUri()
	{
		return $this->settings->isTest() ? self::NZAU_ENV_TEST_TOKEN_REDIRECT_URI : self::NZAU_ENV_LIVE_TOKEN_REDIRECT_URI;
	}

	/**
	 * @return string
	 */
	public function getToken() {
		return $this->settings->isTest() ? self::NZAU_ENV_TEST_TOKEN_URL : self::NZAU_ENV_LIVE_TOKEN_URL;
	}

	/**
	 * @param $transaction_id
	 *
	 * @return string
	 */
	public function getRefund( $transaction_id ) {
		$path = sprintf( ( '/oidc/api/' . self::VERIFONE_PAYMENTS_API_VERSION . '/transactions/%s/' . self::VERIFONE_PAYMENTS_REFUND_PATH ), $transaction_id );

		return $this->settings->isTest() ? self::NZAU_ENV_TEST_PAYMENTS_BASE_URL . $path : self::NZAU_ENV_LIVE_PAYMENTS_BASE_URL . $path;
	}

	/**
	 * @return string
	 */
	public function postCheckout() {
		$path = '/' . self::VERIFONE_API_VERSION . '/' . self::VERIFONE_API_CHECKOUT_PATH;

		return $this->settings->isTest() ? self::NZAU_ENV_TEST_CHECKOUT_URL . $path : self::NZAU_ENV_LIVE_CHECKOUT_URL . $path;
	}

	/**
	 * @param $checkout_id
	 *
	 * @return string
	 */
	public function getCheckout( $checkout_id ) {
		$path = '/' . self::VERIFONE_API_VERSION . '/' . self::VERIFONE_API_CHECKOUT_PATH . '/' . $checkout_id;

		return $this->settings->isTest() ? self::NZAU_ENV_TEST_CHECKOUT_URL . $path : self::NZAU_ENV_LIVE_CHECKOUT_URL . $path;
	}

	/**
	 * @return string
	 */
	public function postCustomer() {
		$path = '/oidc/customer-service/' . self::VERIFONE_API_VERSION . '/' . self::VERIFONE_API_CUSTOMER_PATH;

		return $this->settings->isTest() ? self::NZAU_ENV_TEST_CUSTOMER_URL . $path : self::NZAU_ENV_LIVE_CUSTOMER_URL . $path;
	}

	/**
	 * @param $customer_id
	 *
	 * @return string
	 */
	public function getCustomer( $customer_id ) {
		$path = '/oidc/customer-service/' . self::VERIFONE_API_VERSION . '/' . self::VERIFONE_API_CUSTOMER_PATH . '/' . $customer_id;

		return $this->settings->isTest() ? self::NZAU_ENV_TEST_CUSTOMER_URL . $path : self::NZAU_ENV_LIVE_CUSTOMER_URL . $path;
	}

	/**
	 * @param $payment_contract_id
	 *
	 * @return mixed|string
	 */
	public function getPaymentContract($payment_contract_id) {
		$path = '/oidc/ds-entity-service/' . self::VERIFONE_API_PAYMENT_CONTRACTS . '/' . $payment_contract_id;

		return $this->settings->isTest() ? self::NZAU_ENV_TEST_PAYMENTS_BASE_URL . $path : self::NZAU_ENV_LIVE_PAYMENTS_BASE_URL . $path;
	}

}
