<?php

require_once __DIR__ . '/../bootstrap.php';

class VerifoneHostedCheckoutTest extends \WP_Mock\Tools\TestCase {

	public function test_toArray() {
		$orderMock = $this->getMockBuilder( WC_Order::class )
			->disableOriginalConstructor()
			->setMethods( [ 'get_total', 'get_id' ] )
			->getMock()
		;

		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_total' )
			->willReturn( 10 )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_id' )
			->willReturn( 1 )
		;

		$settings = $this->getMockBuilder( Verifone_Hosted_Cart_Settings::class )
			->disableOriginalConstructor()
			->setMethods( [ 'getPaymentContractId', 'get3dsContractId', 'is3dsEnabled', 'getEntityId' ] )
			->getMock()
		;

		$settings->expects( $this->exactly( 2 ) )
			->method( 'is3dsEnabled' )
			->willReturn( true )
		;
		$settings->expects( $this->exactly( 1 ) )
			->method( 'getPaymentContractId' )
			->willReturn( 1 )
		;
		$settings->expects( $this->exactly( 1 ) )
			->method( 'get3dsContractId' )
			->willReturn( 'test' )
		;
		$settings->expects( $this->exactly( 1 ) )
			->method( 'getEntityId' )
			->willReturn( 'test' )
		;

		$helper = $this->getMockBuilder( Verifone_Hosted_Helper::class )
			->disableOriginalConstructor()
			->setMethods( [ 'getDeviceType' ] )
			->getMock()
		;

		$helper->expects( $this->exactly( 1 ) )
			->method( 'getDeviceType' )
			->willReturn( VERIFONE_ENV_TRANSACTION_MODE_COMPUTER_DEVICE )
		;

		$verifoneHostedCheckout = new Verifone_Hosted_Checkout( $orderMock, $settings, $helper, 1 );

		$data = [
			'customer'          => 1,
			'configurations'    => [
				'card' => [
					'captureNow'        => true,
					'paymentContractId' => 1,
					'threedSecure'      => [
						'threeDSContractId' => 'test',
						'enabled'           => true,
						'transactionMode'   => VERIFONE_ENV_TRANSACTION_MODE_COMPUTER_DEVICE,
					],
				],
			],
			'amount'            => "10",
			'currencyCode'      => strtoupper( get_option( 'woocommerce_currency' ) ),
			'entityId'          => 'test',
			// must be a string
			'merchantReference' => '1',
			'returnUrl'         => add_query_arg( [
				'wc-api' => 'payment_response',
			], home_url( '/' ) ),
		];

		$this->assertEquals( $data, $verifoneHostedCheckout->toArray() );
		// we don't care about the contents, just the length
		$this->assertEquals( strlen( json_encode( $data ) ), strlen( $verifoneHostedCheckout->toJson() ) );
	}

}
