<?php

require_once __DIR__ . '/../bootstrap.php';

class VerifoneHostedCustomerTest extends \WP_Mock\Tools\TestCase {

	public function test_toArray() {
		$orderMock = $this->getMockBuilder( WC_Order::class )
			->disableOriginalConstructor()
			->setMethods( [
				'get_billing_company',
				'get_billing_email',
				'get_billing_address_1',
				'get_billing_city',
				'get_billing_country',
				'get_billing_first_name',
				'get_billing_last_name',
				'get_billing_phone',
				'get_billing_postcode',
				'get_billing_state',
			] )
			->getMock()
		;

		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_state' )
			->willReturn( 'test_state' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_postcode' )
			->willReturn( 'test_post_code' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_phone' )
			->willReturn( 'test_phone' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_last_name' )
			->willReturn( 'test_last_name' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_first_name' )
			->willReturn( 'test_first_name' )
		;
		$orderMock->expects( $this->exactly( 2 ) )
			->method( 'get_billing_company' )
			->willReturn( 'test_company' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_email' )
			->willReturn( 'test_email' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_address_1' )
			->willReturn( 'test_addr_1' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_city' )
			->willReturn( 'test_city' )
		;
		$orderMock->expects( $this->exactly( 1 ) )
			->method( 'get_billing_country' )
			->willReturn( 'test_country' )
		;

		$settings = $this->getMockBuilder( Verifone_Hosted_Cart_Settings::class )
			->disableOriginalConstructor()
			->setMethods( [ 'getEntityId' ] )
			->getMock()
		;

		$settings->expects( $this->exactly( 1 ) )
			->method( 'getEntityId' )
			->willReturn( 'test_entity_id' )
		;

		$verifoneHostedCheckout = new Verifone_Hosted_Customer( $orderMock, $settings );

		$data = [
			'companyName'=> 'test_company',
			'emailAddress'=> 'test_email',
			'entityId'=> 'test_entity_id',
			'billing'=> [
				'address1'    => 'test_addr_1',
				'city'        => 'test_city',
				'countryCode' => 'TEST_COUNTRY',
				'firstName'   => 'test_first_name',
				'lastName'    => 'test_last_name',
				'phone'       => 'test_phone',
				'postalCode'  => 'test_post_code',
				'state'       => 'test_state'
			],
		];

		$this->assertEquals($data, $verifoneHostedCheckout->toArray());
		// we don't care about the contents, just the length
		$this->assertEquals(strlen(json_encode($data)), strlen($verifoneHostedCheckout->toJson()));
	}

}
