<?php

require_once __DIR__ . '/../bootstrap.php';

class VerifoneEmeaApiMapperTest extends \WP_Mock\Tools\TestCase {

	public function test_SettersGetters()
	{
		$settingsMock = $this->getMockBuilder( Verifone_Hosted_Cart_Settings::class )
			->disableOriginalConstructor()
			->setMethods( [ 'isTest' ] )
			->getMock()
		;

		$settingsMock->expects($this->any())
			->method('isTest')
			->willReturn(true);
		$emeaMapper = new Emea_Verifone_Api_Mapper($settingsMock);

		$this->assertSame('https://cst1.test-vam.vfims.com', $emeaMapper->getToken());
		$this->assertSame('https://checkout_cst.dimebox.com/v1/checkout/example_id',
			$emeaMapper->getCheckout('example_id')
		);
		$this->assertSame('https://checkout_cst.dimebox.com/v1/customer/1',
			$emeaMapper->getCustomer(1)
		);
		$this->assertSame('https://cst2.test-gsc.vfims.com/oidc/ds-entity-service/paymentContracts/1',
			$emeaMapper->getPaymentContract(1)
		);

		$this->assertSame('https://cst2.test-gsc.vfims.com/oidc/api/v1/transactions/1/refund',
			$emeaMapper->getRefund(1)
		);

		$this->assertSame('https://checkout_cst.dimebox.com/v1/checkout',
			$emeaMapper->postCheckout()
		);

		$this->assertSame('https://checkout_cst.dimebox.com/v1/customer',
			$emeaMapper->postCustomer()
		);

		//----
		// This basically does nothing atm since we don't have an actual test api available
		$settingsMock = $this->getMockBuilder( Verifone_Hosted_Cart_Settings::class )
			->disableOriginalConstructor()
			->setMethods( [ 'isTest' ] )
			->getMock()
		;

		$settingsMock->expects($this->any())
			->method('isTest')
			->willReturn(false);
		$emeaMapper = new Emea_Verifone_Api_Mapper($settingsMock);

		$this->assertSame('https://cst1.test-vam.vfims.com', $emeaMapper->getToken());
		$this->assertSame('https://checkout_cst.dimebox.com/v1/checkout/example_id',
			$emeaMapper->getCheckout('example_id')
		);
		$this->assertSame('https://checkout_cst.dimebox.com/v1/customer/1',
			$emeaMapper->getCustomer(1)
		);
		$this->assertSame('https://cst2.test-gsc.vfims.com/oidc/ds-entity-service/paymentContracts/1',
			$emeaMapper->getPaymentContract(1)
		);

		$this->assertSame('https://cst2.test-gsc.vfims.com/oidc/api/v1/transactions/1/refund',
			$emeaMapper->getRefund(1)
		);

		$this->assertSame('https://checkout_cst.dimebox.com/v1/checkout',
			$emeaMapper->postCheckout()
		);

		$this->assertSame('https://checkout_cst.dimebox.com/v1/customer',
			$emeaMapper->postCustomer()
		);
	}

}
